@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef INCIDENCEEDITOR_INCIDENCEDATETIME_H
-#define INCIDENCEEDITOR_INCIDENCEDATETIME_H
+#pragma once
 
 #include "incidenceeditor-ng.h"
 
@@ -84,6 +83,7 @@ private Q_SLOTS: /// General
     void updateStartTime(const QTime &newTime);
     void updateStartDate(const QDate &newDate);
     void updateStartSpec();
+    void updateEndSpec();
     void updateStartToolTips();
     void updateEndToolTips();
 
@@ -135,4 +135,3 @@ private:
 };
 }
 
-#endif
